Positions

Struct Positions 

pub struct Positions {
    pub scheme_end: usize,
    pub authority_end: usize,
    pub path_end: usize,
    pub query_end: usize,
}
Cached component boundaries inside an IRI/URI string.

Indices are byte offsets.

  • scheme_end — index one past the : after the scheme (0 if no scheme)
  • authority_end — index one past the last byte of the authority (equals scheme_end if none)
  • path_end — index one past the last byte of the path
  • query_end — index one past the last byte of the query (equals path_end if none)

Fields

scheme_end: usizeauthority_end: usizepath_end: usizequery_end: usize

Implementations

Source

impl Positions

pub const EMPTY: Self