pub struct Positions {
pub scheme_end: usize,
pub authority_end: usize,
pub path_end: usize,
pub query_end: usize,
}Expand description
Cached component boundaries inside an IRI/URI string.
Indices are byte offsets.
scheme_end— index one past the:after the scheme (0 if no scheme)authority_end— index one past the last byte of the authority (equalsscheme_endif none)path_end— index one past the last byte of the pathquery_end— index one past the last byte of the query (equalspath_endif none)
Fields
scheme_end: usizepath_end: usizequery_end: usizeImplementations